space_ex v0.8.0 SpaceEx.SpaceCenter.CommNode
Represents a communication node in the network.
For example, a vessel or the KSC.
Link to this section Summary
Functions
Whether the communication node is a control point, for example a manned vessel
Whether the communication node is on Kerbin
Whether the communication node is a vessel
Name of the communication node
The vessel for this communication node
Link to this section Functions
Link to this function
is_control_point(this)
Whether the communication node is a control point, for example a manned vessel.
Returns: true or false
Link to this function
is_home(this)
Whether the communication node is on Kerbin.
Returns: true or false
Link to this function
is_vessel(this)
Whether the communication node is a vessel.
Returns: true or false
Link to this function
name(this)
Name of the communication node.
Returns: a string
Link to this function
vessel(this)
The vessel for this communication node.
Returns: a reference to a SpaceEx.SpaceCenter.Vessel object