space_ex v0.8.0 SpaceEx.SpaceCenter.Node

Represents a maneuver node.

Can be created using SpaceEx.SpaceCenter.Control.add_node/3.

Link to this section Summary

Functions

Returns the burn vector for the maneuver node

The delta-v of the maneuver node, in meters per second

The direction of the maneuver nodes burn

The magnitude of the maneuver nodes delta-v in the normal direction, in meters per second

The orbit that results from executing the maneuver node

The reference frame that is fixed relative to the maneuver node, and orientated with the orbital prograde/normal/radial directions of the original orbit at the maneuver node’s position

The position vector of the maneuver node in the given reference frame

The magnitude of the maneuver nodes delta-v in the prograde direction, in meters per second

The magnitude of the maneuver nodes delta-v in the radial direction, in meters per second

The reference frame that is fixed relative to the maneuver node’s burn

Returns the remaining burn vector for the maneuver node

Gets the remaining delta-v of the maneuver node, in meters per second

Removes the maneuver node

The delta-v of the maneuver node, in meters per second

The magnitude of the maneuver nodes delta-v in the normal direction, in meters per second

The magnitude of the maneuver nodes delta-v in the prograde direction, in meters per second

The magnitude of the maneuver nodes delta-v in the radial direction, in meters per second

The universal time at which the maneuver will occur, in seconds

The time until the maneuver node will be encountered, in seconds

The universal time at which the maneuver will occur, in seconds

Link to this section Functions

Link to this function burn_vector(this, opts \\ [])

Returns the burn vector for the maneuver node.

Returns a vector whose direction is the direction of the maneuver node burn, and magnitude is the delta-v of the burn in meters per second.

Does not change when executing the maneuver node. See SpaceEx.SpaceCenter.Node.remaining_burn_vector/2.

Returns: {double, double, double}, where double is a high precision decimal

The delta-v of the maneuver node, in meters per second.

Does not change when executing the maneuver node. See SpaceEx.SpaceCenter.Node.remaining_delta_v/1.

Returns: a high precision decimal

Link to this function direction(this, reference_frame)

The direction of the maneuver nodes burn.

Returns the direction as a unit vector.

  • reference_frame — The reference frame that the returned direction is in.

Returns: {double, double, double}, where double is a high precision decimal

The magnitude of the maneuver nodes delta-v in the normal direction, in meters per second.

Returns: a high precision decimal

The orbit that results from executing the maneuver node.

Returns: a reference to a SpaceEx.SpaceCenter.Orbit object

Link to this function orbital_reference_frame(this)

The reference frame that is fixed relative to the maneuver node, and orientated with the orbital prograde/normal/radial directions of the original orbit at the maneuver node’s position.

  • The origin is at the position of the maneuver node.

  • The x-axis points in the orbital anti-radial direction of the original orbit, at the position of the maneuver node.

  • The y-axis points in the orbital prograde direction of the original orbit, at the position of the maneuver node.

  • The z-axis points in the orbital normal direction of the original orbit, at the position of the maneuver node.

Returns: a reference to a SpaceEx.SpaceCenter.ReferenceFrame object

Link to this function position(this, reference_frame)

The position vector of the maneuver node in the given reference frame.

Returns the position as a vector.

  • reference_frame — The reference frame that the returned position vector is in.

Returns: {double, double, double}, where double is a high precision decimal

The magnitude of the maneuver nodes delta-v in the prograde direction, in meters per second.

Returns: a high precision decimal

The magnitude of the maneuver nodes delta-v in the radial direction, in meters per second.

Returns: a high precision decimal

Link to this function reference_frame(this)

The reference frame that is fixed relative to the maneuver node’s burn.

  • The origin is at the position of the maneuver node.

  • The y-axis points in the direction of the burn.

  • The x-axis and z-axis point in arbitrary but fixed directions.

Returns: a reference to a SpaceEx.SpaceCenter.ReferenceFrame object

Link to this function remaining_burn_vector(this, opts \\ [])

Returns the remaining burn vector for the maneuver node.

Returns a vector whose direction is the direction of the maneuver node burn, and magnitude is the delta-v of the burn in meters per second.

Changes as the maneuver node is executed. See SpaceEx.SpaceCenter.Node.burn_vector/2.

Returns: {double, double, double}, where double is a high precision decimal

Link to this function remaining_delta_v(this)

Gets the remaining delta-v of the maneuver node, in meters per second.

Changes as the node is executed. This is equivalent to the delta-v reported in-game.

Returns: a high precision decimal

Removes the maneuver node.

Returns: :ok

Link to this function set_delta_v(this, value)

The delta-v of the maneuver node, in meters per second.

Does not change when executing the maneuver node. See SpaceEx.SpaceCenter.Node.remaining_delta_v/1.

Returns: :ok

Link to this function set_normal(this, value)

The magnitude of the maneuver nodes delta-v in the normal direction, in meters per second.

Returns: :ok

Link to this function set_prograde(this, value)

The magnitude of the maneuver nodes delta-v in the prograde direction, in meters per second.

Returns: :ok

Link to this function set_radial(this, value)

The magnitude of the maneuver nodes delta-v in the radial direction, in meters per second.

Returns: :ok

Link to this function set_ut(this, value)

The universal time at which the maneuver will occur, in seconds.

Returns: :ok

The time until the maneuver node will be encountered, in seconds.

Returns: a high precision decimal

The universal time at which the maneuver will occur, in seconds.

Returns: a high precision decimal