space_ex v0.8.0 SpaceEx.SpaceCenter.SolarPanel

A solar panel.

Obtained by calling SpaceEx.SpaceCenter.Part.solar_panel/1.

Link to this section Summary

Functions

Whether the solar panel is deployable

Whether the solar panel is extended

The current amount of energy being generated by the solar panel, in units of charge per second

The part object for this solar panel

Whether the solar panel is extended

The current state of the solar panel

The current amount of sunlight that is incident on the solar panel, as a percentage

Link to this section Functions

Link to this function deployable(this)

Whether the solar panel is deployable.

Returns: true or false

Whether the solar panel is extended.

Returns: true or false

Link to this function energy_flow(this)

The current amount of energy being generated by the solar panel, in units of charge per second.

Returns: a low-precision decimal

The part object for this solar panel.

Returns: a reference to a SpaceEx.SpaceCenter.Part object

Link to this function set_deployed(this, value)

Whether the solar panel is extended.

Returns: :ok

The current state of the solar panel.

Returns: a Elixir.SpaceEx.SpaceCenter.SolarPanelState value in atom form

Link to this function sun_exposure(this)

The current amount of sunlight that is incident on the solar panel, as a percentage.

A value between 0 and 1.

Returns: a low-precision decimal