space_ex v0.5.0 SpaceEx.RemoteTech
This service provides functionality to interact with RemoteTech.
Link to this section Summary
Functions
Get the antenna object for a particular part
Whether RemoteTech is installed
Get a communications object, representing the communication capability of a particular vessel
The names of the ground stations
Link to this section Functions
Link to this function
antenna(conn, part, opts \\ [])
Get the antenna object for a particular part.
Link to this function
available(conn, opts \\ [])
Whether RemoteTech is installed.
Link to this function
comms(conn, vessel, opts \\ [])
Get a communications object, representing the communication capability of a particular vessel.
Link to this function
ground_stations(conn, opts \\ [])
The names of the ground stations.