space_ex v0.5.0 SpaceEx.SpaceCenter.Radiator
A radiator.
Obtained by calling SpaceEx.SpaceCenter.Part.radiator/1.
Link to this section Summary
Functions
Whether the radiator is deployable
For a deployable radiator, true if the radiator is extended
The part object for this radiator
For a deployable radiator, true if the radiator is extended
The current state of the radiator
Link to this section Functions
Link to this function
deployable(this, opts \\ [])
Whether the radiator is deployable.
Link to this function
deployed(this, opts \\ [])
For a deployable radiator, true if the radiator is extended.
If the radiator is not deployable, this is always true.
Link to this function
part(this, opts \\ [])
The part object for this radiator.
Link to this function
set_deployed(this, value, opts \\ [])
For a deployable radiator, true if the radiator is extended.
If the radiator is not deployable, this is always true.
Link to this function
state(this, opts \\ [])
The current state of the radiator.
A fixed radiator is always SpaceEx.SpaceCenter.RadiatorState.extended.